Module authentication

Module authentication 

Available on crate features client or server only.
Common types for implementing federation authorization.

Structs

ServerSignatures
Authentication is performed by adding an X-Matrix authentication scheme as the request Authorization HTTP header, as defined in the Matrix Server-Server API.
XMatrix
Typed representation of an X-Matrix authentication scheme, as defined in the Matrix Server-Server API.
XMatrixSigningInput
The input necessary to generate an X-Matrix authentication scheme by signing an HTTP request.

Enums

XMatrixExtractError
An error when trying to extract an XMatrix from the headers of an HTTP request.
XMatrixFromRequestError
An error when trying to construct an XMatrix from a http::Request.
XMatrixParseError
An error when trying to parse an X-Matrix Authorization header.
XMatrixVerificationError
An error when trying to verify the signature in an XMatrix for an HTTP request.